function image = svaNT( command, argument )
%
%SVANT  Acquires raw images from a svavisca giotto log-polar camera
%
%   PARAMETERS:
%
%      command - Can be one of the following: 
%
%         'init' - Initializes the camera driver and sets up acquisition. 
%                  Must be executed once in the beginning of the session.
%
%         'end'  - Closes the camera driver.
%                  Must be executed once in the end of the session.
%
%	  'acq'  - Acquires one frame.
%
%      argument - The index of the parallel port ( 1 | 2 | 3 | 4 | 5 )
%
%	EXAMPLES: 
%                  svaNT('init', 1);     		-- initializes LPT1
% 		   svaNT('init', 2);     		-- initializes LPT2
%                  img1 = svaNT('acq', 1);              -- grabs image from LPT1
%                  img2 = svaNT('acq', 2);              -- grabs image from LPT2
%		   svaNT('end', 1);	                -- closes LPT1
%		   svaNT('end', 2);	                -- closes LPT2
%
%	VERSION: 1.0
%
%	NOTE: The output image pixels are 'uint8' class.  
%
%	COPYRIGHT: UNITEK

%   AUTHOR: Pedro Soares (psoares@observit.com.pt)
%